@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 ##########################################################################
 # Ganga Project. http://cern.ch/ganga
 #
@@ -28,7 +28,7 @@ from GangaCore.Core.exceptions import GangaException
 
 import GangaCore.Utility.Config
 
-regex = re.compile('[*?\[\]]')
+regex = re.compile(r'[*?\[\]]')
 logger = getLogger()
 
 class MassStorageFile(IGangaFile):
@@ -204,7 +204,7 @@ class MassStorageFile(IGangaFile):
 
         replace_dict = { '###INDENT###' : indent, '###CP_COMMAND###' : cp_cmd }
 
-        for k, v in replace_dict.iteritems():
+        for k, v in replace_dict.items():
             script = script.replace(str(k), str(v))
 
         return script
@@ -231,7 +231,7 @@ class MassStorageFile(IGangaFile):
             self.handleUploadFailure(mystderr, '1) %s %s' % (ls_cmd, pathToDirName))
             raise GangaException(mystderr)
 
-        for directory in mystdout.split('\n'):
+        for directory in mystdout.decode().split('\n'):
             if directory.strip() == dirName:
                 directoryExists = True
                 break
@@ -281,7 +281,7 @@ class MassStorageFile(IGangaFile):
 
         cp_cmd = massStorageConfig['cp_cmd']
         ls_cmd = massStorageConfig['ls_cmd']
-        massStoragePath = massStorageConfig['path']
+        massStoragePath = os.path.expanduser(os.path.expandvars(massStorageConfig['path']))
 
         try:
             self._mkdir(massStoragePath, exitIfNotExist=True)
@@ -434,7 +434,7 @@ class MassStorageFile(IGangaFile):
 
             massStorageCommands.append(['massstorage', outputFile.namePattern, outputfilenameformat,
                                         massStorageConfig['mkdir_cmd'],  massStorageConfig['cp_cmd'],
-                                        massStorageConfig['ls_cmd'], massStorageConfig['path']])
+                                        massStorageConfig['ls_cmd'], os.path.expanduser(os.path.expandvars(massStorageConfig['path']))])
 
         script_location = os.path.join(os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe()))),
                                         'scripts/MassStorageFileWNScript.py.template')
@@ -459,7 +459,7 @@ class MassStorageFile(IGangaFile):
                         '###JOBDIR###' : str(jobid),
                         '###SUBJOBDIR###' : str(subjobid)}
 
-        for k, v in replace_dict.iteritems():
+        for k, v in replace_dict.items():
             script = script.replace(str(k), str(v))
 
         return script
@@ -499,7 +499,7 @@ class MassStorageFile(IGangaFile):
                 keyin = None
 
                 while keyin is None:
-                    keyin = raw_input("Do you want to delete file %s at Location: %s ? [y/n] " % (str(self.namePattern), str(i)))
+                    keyin = input("Do you want to delete file %s at Location: %s ? [y/n] " % (str(self.namePattern), str(i)))
                     if keyin.lower() == 'y':
                         _delete_this = True
                     elif keyin.lower() == 'n':
@@ -535,7 +535,7 @@ class MassStorageFile(IGangaFile):
 
                     keyin = None
                     while keyin is None:
-                        keyin = raw_input("Do you want to remove the local File: %s ? ([y]/n) " % str(_localFile))
+                        keyin = input("Do you want to remove the local File: %s ? ([y]/n) " % str(_localFile))
                         if keyin.lower() in ['y', '']:
                             _actual_delete = True
                         elif keyin.lower() == 'n':
