@@ -1,9 +1,10 @@
-from __future__ import absolute_import
+
 from GangaCore.Core.exceptions import ApplicationConfigurationError
 from GangaCore.GPIDev.Schema import Schema, Version, SimpleItem, ComponentItem
 from GangaCore.Utility.logging import getLogger
 from GangaCore.GPIDev.Lib.Tasks.ITransform import ITransform
 from GangaCore.GPIDev.Lib.Tasks.CoreUnit import CoreUnit
+from GangaCore.GPIDev.Lib.Tasks.TaskChainInput import TaskChainInput
 from GangaCore.GPIDev.Lib.Dataset.GangaDataset import GangaDataset
 from GangaCore.GPIDev.Lib.Job.Job import Job
 from GangaCore.GPIDev.Base.Proxy import stripProxy, getName, isType
@@ -14,12 +15,12 @@ import re
 logger = getLogger()
 
 class CoreTransform(ITransform):
-    _schema = Schema(Version(1, 0), dict(ITransform._schema.datadict.items() + {
+    _schema = Schema(Version(1, 0), dict(list(ITransform._schema.datadict.items()) + list({
         'unit_splitter': ComponentItem('splitters', defvalue=None, optional=1, load_default=False, doc='Splitter to be used to create the units'),
         'chaindata_as_inputfiles': SimpleItem(defvalue=False, doc="Treat the inputdata as inputfiles, i.e. copy the inputdata to the WN"),
         'files_per_unit': SimpleItem(defvalue=-1, doc="Number of files per unit if possible. Set to -1 to just create a unit per input dataset"),
         'fields_to_copy': SimpleItem(defvalue=[], typelist=[str], sequence=1, doc='A list of fields that should be copied when creating units, e.g. application, inputfiles. Empty (default) implies all fields are copied unless the GeenricSplitter is used '),
-    }.items()))
+    }.items())))
 
     _category = 'transforms'
     _name = 'CoreTransform'
@@ -110,8 +111,6 @@ class CoreTransform(ITransform):
                     unit.name = "Unit %d" % len(self.units)
                     unit.inputdata = GangaDataset(
                         files=filelist[fid:fid + self.files_per_unit])
-                    unit.inputdata.treat_as_inputfiles = self.inputdata[
-                        0].treat_as_inputfiles
 
                     fid += self.files_per_unit
 
@@ -161,6 +160,5 @@ class CoreTransform(ITransform):
         unit = CoreUnit()
         unit.name = "Unit %d" % len(self.units)
         unit.inputdata = GangaDataset(files=flist)
-        unit.inputdata.treat_as_inputfiles = self.chaindata_as_inputfiles
 
         return unit
