@@ -438,7 +438,6 @@ under certain conditions; type license() for details.
 
             logger.info("IPython history migrated successfully.")
 
-
     @staticmethod
     def generate_config_file(config_file, interactive):
         from GangaCore.GPIDev.Lib.Config.Config import config_file_as_text
@@ -729,7 +728,7 @@ under certain conditions; type license() for details.
                 gangaver = _versionsort(new_version_format_to_old(_gangaVersion).lstrip('Ganga-'))  # Site config system expects x-y-z version encoding
                 for d in dirlist:
                     vsort = _versionsort(d)
-                    if vsort and ((vsort <= gangaver) or (gangaver is 'SVN')):
+                    if vsort and ((vsort <= gangaver) or (gangaver == 'SVN')):
                         select = os.path.join(this_dir, d)
                         config_files.append(_createpath(select))
                         break
@@ -1011,8 +1010,8 @@ under certain conditions; type license() for details.
         logger.debug("Entering run")
 
         if self.options.webgui == True:
-            from GangaCore.Runtime.http_server import start_server
-            start_server()
+            from GangaGUI.start import start_gui
+            start_gui()
 
         if local_ns is None:
             import __main__
