@@ -2,6 +2,7 @@
 import os
 import inspect
 import GangaCore.Utility.Virtualization
+from GangaCore import _gangaVersion
 from GangaCore.Core.Sandbox.WNSandbox import PYTHON_DIR
 from GangaDirac.Lib.RTHandlers.DiracRTHUtils import dirac_inputdata, dirac_ouputdata, mangle_job_name, diracAPI_script_template, diracAPI_script_settings, API_nullifier, dirac_outputfile_jdl
 from GangaDirac.Lib.Files.DiracFile import DiracFile
@@ -117,12 +118,15 @@ class ExeDiracRTHandler(IRuntimeHandler):
                                         OUTPUT_PATH="",  # job.fqid,
                                         SETTINGS=diracAPI_script_settings(app),
                                         DIRAC_OPTS=job.backend.diracOpts,
+                                        MIN_PROCESSORS=job.backend.minProcessors,
+                                        MAX_PROCESSORS=job.backend.maxProcessors,
                                         PLATFORM=platform,
                                         REPLICATE='True' if config['ReplicateOutputData'] else '',
                                         # leave the sandbox for altering later as needs
                                         # to be done in backend.submit to combine master.
                                         # Note only using 2 #s as auto-remove 3
-                                        INPUT_SANDBOX='##INPUT_SANDBOX##'
+                                        INPUT_SANDBOX='##INPUT_SANDBOX##',
+                                        GANGA_VERSION=_gangaVersion,
                                         )
 
         #logger.info("dirac_script: %s" % dirac_script)
@@ -181,6 +185,12 @@ print("files on WN: " + str(listdir('.')))
 
 ###OUTPUTFILESINJECTEDCODE###
 
+try:
+    subprocess.call('chmod -R u+rwX  * .*', env=runenv, shell=True)
+except Exception as x:
+    print('Problems fixing permissions on output files to allow for clean-up.')
+    print('Err was: ' + str(x))
+
 sys.exit(rc)
 """
     return script_template
